package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````Z`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)`````````!]TR6(.;)+
MVSFR2]LYLDO;NJY%VSNR2]M6K4';,K)+VU:M3]L[LDO;6ZU8VSVR2]M"KD?;
M.[)+VSFR2MMKLDO;QI)/VSJR2]L/E$';.[)+VX&T3=LXLDO;4FEC:#FR2]L`
M`````````%!%``!,`00`0$;620``````````X``/`0L!!@``,````*``````
M``#`.0```!````!``````$```!`````0```$``````````0``````````.``
M```0``"RS@$``P``````$```$``````0```0````````$```````````````
M#*$``&0`````P```T!$``````````````````````````````````#!!```<
M``````````````````````````````````````````````````````````!`
M```L`0``````````````````````````````````+G1E>'0```#\*@```!``
M```P````$```````````````````(```8"YR9&%T80``"F<```!`````<```
M`$```````````````````$```$`N9&%T80```&0$````L````!````"P````
M``````````````!```#`+G)S<F,```#0$0```,`````@````P```````````
M````````0```P```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%:^B$%``%9HRCA``&AL04``Z*XH``!0Z*(H``"#Q!!6:+@X0`!H5$%``.B5
M*```4.B)*```@\007L-5B^R![`@$``!35E=HL$%``.BH`0``B47\C87X^___
MQP0D``0``#/;4%/_%0A`0`"%P`^%3`$``/\U$+!``(MU"%;_%8A`0`!9687`
M5G03:*!!0`#H\P$``%F+QEGI5P$``.C5*```_S44L$``BSV00$``B47X_W4,
M_]>#Q`R+\#OS#X0?`0``.!YU!;Z<04``.5W\=!-6_W7\Z)<H``!9A<!9#X3+
M````5NB-*```BE0P_UF+#1"P0``Z$74*2(@<!HI4!O_K[(M5^/]U"(U$$`$]
M``0```^-S0```%%6C87X^___:)1!0`!0_Q680$``Z)0G``!0Z*`G``"+,.B'
M)P``4.B-)P``@\0<4(V%^/O__U#H<2<``%#H?2<``%G_,/]64(/$#(7`=4CH
M62<``%#H7R<``&:+0`999B4`\&8]`(!U+N@_)P``4.A+)P``BS!9C87X^___
M:@%0Z"@G``!0Z#0G``!9_S#_%H/$#(7`=!#_-12P0`!3_]=96>GZ_O__C87X
M^___4&B@04``Z+<```"-A?C[__]0_Q5$0$``@\0,ZQ+_=0AHH$%``.B8````
MBT4(65E?7EO)PU6+[(U%"%#_=0CH!````%E97<-5B^Q14U:+=0A7A?9T9HL=
MA$!``/_3@S@`=%F*#HO&A,ET"X#Y/70&BD@!0.OQ*\:)1?S_TXLPBSZ%_W0W
M_W7\_W4(5_\50$!``(/$#(7`=0F+1?R`/`<]=`6#Q@3KV/_3*S"+10S!_@*)
M,(M%_(U$!P'K`C/`7UY;R<-5B^Q148M%#(`X/74#_T4,4U97_W4,Z-4F``"+
M70B)1?B-1?Q04^A:____BS6$0$``B_B#Q`R%_W0B5^BP)@``.T7X60^"RP``
M`(M-#(H!B`='083`=?;I/`$``/_6BP`S_S/).0AT!H/`!$?K]CD-1+1``'1`
MZ,,E``!0Z-4E``"+&%F-!+T(````4/_6_S#HJ24``%#HNR4``%G_,/]3!(/$
M#(O8_]:)&/_6@S@`=57IL0```,<%1+1```$```#H>24``%#HBR4``(L868T$
MO0@```!0Z&,E``!0Z'4E``!9_S#_$XO8687;671YB\?!X`)0_];_,%/_%8!`
M0`"#Q`S_UHD8_]:+`(M="(-DN`0`B7W\B@.+^X3`=`H\/70&BD<!1^ORZ!(E
M``!0Z"0E``"+$(M%^"O[68E5"(U$!P)0Z/<D``!0Z`DE``!9_S"+10C_$%F+
M^%G_UHL`BTW\A?^)/(AU!8/(_^LN_]:+`(M-_(L$B(H+0X3)B`AT"(#Y/70#
M0.OOBU4,Q@`]0(H*B`A`0H3)=?8SP%]>6\G#BT0D!%:+\(O(B@"$P'07BQ40
ML$``BA(ZPG4#C7$!BD$!083`=?&+QE[#5HMT)`B%]G1O@#X`=&I6Z!,E``"-
M1##_68L-$+!``#O&=A:*$3@0=05(.\9W]SO&=@DX$'0#2.OU.\9U"8H`.@%T
M-5'K-T@[QG8&BA`Z$73U*\:-2`*!^0`$``!V!#/`7L-`4%:^/+!``%;_%7Q`
M0`"#Q`R+QE[#:)Q!0`#_%41`0`!97L-5B^R#["135E=J"%F^A$)``(U]W&AT
M0D``\Z5FI>@)`0``QP0D:$)``.C]````N[!!0`!3Z/(```"^7$)``%;HYP``
M`+]00D``5^C<````:$1"0`#HT@```&B@04``Z,@```!H.$)``.B^````:"Q"
M0`#HM````&@80D``Z*+\__^#Q"2%P'0)4%?H(OW__UE9:`1"0`#HB/S__X7`
M670-4&CX04``Z`;]__]966CH04``Z&S\__^%P%ET"U!3Z.[\__]96>M.:-1!
M0`#H4OS__X7`670$4%;KY&C,04``Z+TC``"_P$%``(U<!>A7Z*XC``!05U/_
M%7A`0`"#Q!2%P'425^B8(P```\-05NB?_/__@\0,:+Q!0`!H=$)``.B-_/__
M65E?7EO)PU6+[%&-1?Q0_W4(Z/O[__]9A<!9=![_%81`0`"+`(M-_(T,B(M1
M!(U!!(72B1%TU(O(Z_#)PZ$8L$``@_C_=25H7$)``.BN^___A<!9=`^*`(3`
M=`D\,'0%:@%8ZP(SP*,8L$``PS/`PU6+[(/L(+C@0D``5XOX4(E%X,=%Y-A"
M0`#'1>C(0D``QT7LP$)``,=%\*Q"0`#'1?2H0D``B7WXZ-`B``"%P%D/AL0`
M``"-1>!35HE%_%?H._O__XOP687V#X2#````5NBH(@``A<!9='C_=0A6_Q6(
M0$``687`675SZ-PA``!0Z.XA``#_-12P0`"+..A[(@``5HO8Z',B``#_=0@#
MV.AI(@``@\00C40#`E#HJB$``%#HO"$``%G_,/\75HOX_S44L$``_W4(:)1!
M0`!7_Q680$``5_]U^.A`^___@\0DZPO_=0A7Z#+[__]968-%_`2+1?R+.%>)
M??CH#B(``(7`60^'1O___UY;7\G#58OLN."```#H_2$``(-E_`!6N*A"0`!H
ML$%``,=%V(A#0`#'1=Q004``QT7@G$%``(E%Y,=%P/A!0`#'1<2`0T``QT7(
M>$-``,=%S'!#0`#'1=!L0T``B474QT7H9$-``,=%[%A#0`")1?#H$OK__XOP
M687V=!]6Z(,A``"%P%ET%%;H:_[__U;_%41`0`!96>G7`P``4[X`!```5XEU
M^.BI(```4.B[(```BSA95NB:(```4.BL(```6?\P_Q=968U-^%%0_Q4`0$``
MZ!_^__^+V(7;B5WX=3V-?>B+-U;H&R$``(7`678@5NB2^?__A<!9=`M0_Q5$
M0$``68E%^(M=^(/'!(7;=-.%VW4)QT7X4$-``.M#@#L`B_-T/+\'`0``H61`
M0`"#.`%^#P^^!E=0_Q5H0$``65GK$8L-;$!```^^!HL)9HL$02/'A<!U`\8&
M7T:`/@!UR8U]P(LW5NB;(```A<!9=BQ6Z!+Y__^+\%F%]G065N@*&0``A<!9
M=`M6_Q5$0$``68E%_(/'!(-]_`!TQX-]_`"+-9A`0`!U>6A(0T``Z-;X__^+
MV%F%VW1HZ)8?``!0Z*@?``"+.%/H.B```%F#P`994.A]'P``4.B/'P``6?\P
M_Q>+^%-H0$-``%?_UE?HFA@``(/$&(7`=`6)??SK(NA0'P``4.AB'P``BQA9
M5^A!'P``4.A3'P``6?\P_U,(65F#??P`=2^-7=B+.U?HU!\``(7`678?5^A0
M&```A<!9=`M7_Q5$0$``68E%_(/#!(-]_`!TU/]U^.BH'P``_W7\B_CHGA\`
M`+LX0T```_A3Z)$?``!HJ$)```/XZ(4?``"-O`<`!```Z,<>``!0Z-D>``"+
M$(/$%(E5]%?HLQX``%#HQ1X``%G_,(M%]/\0_W7XB_A3_S40L$``_W7\:"Q#
M0`!7_]97_Q5P0$``:,!"0`#HL??__XM="(/$*(7`=!E0_Q5$0$``4/\SZ-KU
M__^#Q`R)10B%P'4%BP.)10CHPOO__X7`#X5.`@``Z$,>``!0Z$\>``"+&,<$
M)`"```#_=0CH+!X``%#H.!X``%G_,/]3/(/$#(E%"(7`#X08`@``Z`T>``!0
MZ!D>``!9BQAJ`FK_:N[_=0CH]AT``%#H`AX``%G_,/]3,.CE'0``4.CQ'0``
MBQB#Q!B-A2!___]J!E#_=0CHR1T``%#HU1T``%G_,/]31(/$$("]('___P`/
MA<\```"`O2%___]##X7"````@+TB?___00^%M0```("](W___T,/A:@```"`
MO21___](#X6;````@+TE?___10^%C@```.AG'0``4.AS'0``68L8:@)J_VK&
M_W4(Z%`=``!0Z%P=``!9_S#_4S#H/QT``%#H2QT``(L8@\08C84@?___:BE0
M_W4(Z",=``!0Z"\=``!9_S#_4T2-A2!___]HJ$)``%#_-1"P0`!7:!Q#0`!7
M_]:#Q"A7:+!!0`#HL/;__U?HC?K__X/$#(O'7UM>R<.-A2#___]0Z)T!``#H
MS1P``%#HV1P``%E9BQB-A2!___]H`(```%#_=0CHKQP``%#HNQP``%G_,/]3
M1(/$$(7`?B10C84@?___4(V%(/___U#HA0$``.B#'```4.B/'```@\00Z[/H
M<QP``%#H?QP``(L86?]U".AB'```4.AN'```6?\P_U,0C84@____4(U%K%#H
M(A0``(U%@(/$$#/;B44(#[9$':Q0:!1#0`#_=0C_UH-%"`*#Q`Q#@_L4?..-
M18!HJ$)``(!EJ`!0_S40L$``5V@<0T``5__6@\08Z0'___^#90@`5^BB'```
MQP0DO$%``&A<0D``B47TZ)[U__]966BH0D``Z-`;``!0Z.@;``"+&.C#&P``
M4.C;&P``_S#_4VB#Q`Q0_S40L$``5V@$0T``5__65_\5<$!``(/$'(/X_P^%
MF?[___\5=$!``(,X$0^%BO[__XM%]&BH0D``@"0X`/]%"/]U".AL&P``4.B$
M&P``BQCH7QL``%#H=QL``/\P_U-H@\0,4/\U$+!``%=H\$)``%?_UE?_%7!`
M0`"#Q"#KFHM$)`0SR<<``2-%9\=`!(FKS>_'0`C^W+J8QT`,=E0R$,=`$/#A
MTL.)2!2)2!B)2%S#58OL4XM=$%:+=0A7BTX4C039.\%S`_]&&(E&%(O#P>@=
M`488BT9<A<!T-&I`7ROX._M^`HO[BT9<5_]U#(U$!AQ0Z*@;```!?0P!?ER#
MQ`PKWX-^7$!U2U;H2@```%F#^T!\+(O[P>\&B\?WV,'@!@/8:D"-1AS_=0Q0
MZ&\;``"#10Q`5N@>````@\003W7B4XU&'/]U#%#H4AL``(/$#(E>7%]>6UW#
M58OL@>Q4`0``BT4(4U97C5`<C;6L_O__QT4($````(L*@\($B_F+V8'G``#_
M`,'K$`O[B]F!XP#_``#!X1`+V<'O",'C"`O[B3Z#Q@3_30AUS6I`C96T_O__
M7HM*+#-*&#-*^#,*@\($B_D#R<'O'POY3HEZ-'7CBW@$BU`(BW`,BPB+WR/7
M]],CWHOQ"]J+T<'J&\'F!0O6BW`0`_,#UHNUK/[__XV4,IEY@EJ+]\'F'L'O
M`@OWB_GWUR-X"(EU["/QB]H+_HORP>L;P>8%"]Z+M;#^__\#]P/>BW`,C;PS
MF7F"6HOQB]F)??C!YA[!ZP(+\XO:]],C7>R)=?PC\@O>B[6T_O__B5T(B]_!
MZQO!YP4+WXM]"`/WB_K!YQ[!Z@(#WHMP"`OZBU7XC;0SF7F"6HM=^/?2(U7\
M(]^)??2+_@O3B][![QO!XP4+^XN=N/[__P/:`_N+5>R-G!>9>8):BWWXB]>)
M70C!XA[![P(+UXO^]]<C??2)5?@CU@OZB]/!ZAO!XP4+TXN=O/[__P/?BWW\
M`].-E#J9>8):B_[!YQ[![@(+_HMU"/?6(W7XB7WP(WT(B]K!XP4+]XOZP>\;
M"_N+G<#^__\#WHMU]`/[C9PWF7F"6HM]"(OWB5W\P>8>P>\""_>+^O?7(WWP
MB74((_(+_HOSP>X;P>,%"_.+G<3^__\#WXM]^`/SC;0^F7F"6HOZP><>P>H"
M"_J+5?SWTB-5"(E]["-]_(O>P>,%"]>+_L'O&PO[BYW(_O__`]J+5?`#^XV<
M%YEY@EJ+??R+UXE=^,'B'L'O`@O7B_[WUR-][(E5_"/6"_J+T\'J&\'C!0O3
MBYW,_O__`]^+?0@#TXM=^(V4.IEY@EJ+_L'G'L'N`@O^BW7X]]8C=?PCWXE]
M](OZ"_.+VL'O&\'C!0O[BYW0_O__`]Z+=>P#^XV<-YEY@EJ+??B+]XE=",'F
M'L'O`@OWB_KWUR-]](EU^"/R"_Z+\\'N&\'C!0OSBYW4_O__`]^+??P#\XVT
M/IEY@EJ+^L'G'L'J`@OZBU4(]](C5?B)??`C?0B+WL'C!0O7B_[![QL+^XN=
MV/[__P/:BU7T`_N-G!>9>8):BWT(B]>)7?S!XA[![P(+UXO^]]<C??")50@C
MU@OZB]/!ZAO!XP4+TXN=W/[__P/?BWWX`].-E#J9>8):B_[!YQ[![@(+_HMU
M_/?6(W4(B7WL(WW\B]K!XP4+]XOZP>\;"_N+G>#^__\#WHMU\`/[C9PWF7F"
M6HM]_(OWB5WXP>8>P>\""_>+^O?7(WWLB77\(_(+_HOSP>X;P>,%"_.+G>3^
M__\#WXM]"`/SBUWXC;0^F7F"6HOZP><>P>H""_J+5?CWTB-5_(E]]"/?B_X+
MTXO>P>\;P>,%"_N+G>C^__\#VHM5[`/[C9P7F7F"6HM]^(O7B5T(P>(>P>\"
M"]>+_O?7(WWTB57X(]8+^HO3P>H;P>,%"].+G>S^__\#WXM]_`/3C90ZF7F"
M6HO^P><>P>X""_Z+=0CWUB-U^(E]\"-]"(O:P>,%"_>+^L'O&PO[BYWP_O__
M`]Z+=?0#^XV<-YEY@EJ+?0B+]XE=_,'F'L'O`@OWB_KWUR-]\(EU""/R"_Z+
M\\'N&\'C!0OSBYWT_O__`]^+??@#\XVT/IEY@EJ+^L'G'L'J`@OZBU7\]](C
M50B)?>PC??P+UXO^P>\;B][!XP4+^XN=^/[__P/:BU7P`_N-G!>9>8):BWW\
MB]>)7?C!XA[![P(+UXO[P>\;P>,%"_N+7>R)5?PSVHN5_/[__S/>`]>+_@/:
MBU4(P><>P>X""_Z-E!.AZ]ENB7WTB_*+^HN=`/___\'N&\'G!0OWBWWX,WW\
M`]Z+=>PS??0#^XV<-Z'KV6Z+??B+]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+
M^XN=!/___S/R,W7T`]^+??P#\XVT/J'KV6Z+^L'G'L'J`@OZB]:+WHE]\,'J
M&\'C!0O3BUWX,]^+O0C___\S70@#^HM5]`/?C9P3H>O9;HM]"(E=_(O7P>(>
MP>\""]>+^\'O&\'C!0O[BUWPB54(,]J+E0S___\SW@/7B_X#VHM5^,'G'L'N
M`HV4$Z'KV6X+_HORB]K![AO!XP4+\XM="(E][#/?B[T0____,UW\`_Z+=?`#
MWXM]_(V<,Z'KV6Z+]\'F'L'O`@OWB_N)7?B)=?S![QO!XP4+^XM=[#/>B[44
M____,]H#]XOZ`]Z+=0C!YQ[!Z@(+^HVT,Z'KV6Z)??2+UHO^BYT8____P>H;
MP><%"]>+??@S??P#VHM5[#-]]`/[C9P7H>O9;HM]^(O7B5T(P>(>P>\""]>)
M5?B+^S/6,U7TP>\;P>,%"_N+G1S___\#WXM]_`/3C90ZH>O9;HO^P><>P>X"
M"_Z+\HO:B7WPP>X;P>,%"_.+7?@SWXN](/___S-="`/^BW7T`]^+?0B-G#.A
MZ]ENB_?!YA[![P(+]XO[B5W\B74(P>\;P>,%"_N+7?`SWHNU)/___S/:`_<#
MWHMU^(OZP><>P>H"C;0SH>O9;@OZB]:+WL'J&\'C!0O3BUT(B7WL,]^+O2C_
M__\S7?P#^HM5\`/?BWW\C9P3H>O9;HO7P>(>P>\""]>+^XE=^(E5_,'O&\'C
M!0O[BUWL,]J+E2S___\SW@/7B_X#VHM5",'G'L'N`@O^C903H>O9;HE]](OR
MB_J+G3#____![AO!YP4+]XM]^#-]_`/>BW7L,WWT`_N-G#>AZ]ENBWWXB_>)
M70C!YA[![P(+]XO[P>\;P>,%B77X"_N+G33___\S\C-U]`/?BWW\`_.-M#ZA
MZ]ENB_K!YQ[!Z@(+^HO6B]Z)??#!ZAO!XP4+TXM=^#/?B[TX____,UT(`_J+
M5?0#WXM]"(V<$Z'KV6Z+U\'B'L'O`@O7B_N)7?R)50C![QO!XP4+^XM=\#/:
MBY4\____,]X#UP/:BU7XC;P3H>O9;HO6P>(>P>X""]:+]XO?P>X;P>,%"_.+
M70B)5>PSVHN50/___S-=_`/6BW7\`]J+5?"-G!.AZ]ENB];!XA[![@(+UHOS
MB5WXB57\P>X;P>,%"_.+7>PSVHN51/___S/?`]:+]P/:BU4(P>8>P>\""_>-
ME!.AZ]ENB77TB_*+^HN=2/___\'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XVT
M-Z'KV6Z+??B)=0B+]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7TP>,%"_Z+
M=0C![AL+\XN=3/___P/?BWW\`_.-M#[<O!N/B_K!YQ[!Z@(+^HO7B7WP"U4(
M(U7X(WT(B]X+UXO^P>\;P>,%"_N+G5#___\#VHM5]`/[C9P7W+P;CXM]"(O7
MB5W\P>(>P>\""]>+^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+G53___\#WXM]
M^`/3C90ZW+P;CXO^P><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O
M&PO[BYU8____`]Z+=?`#^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+
M^B/R(WWL"_Z+\\'N&\'C!0OSBYU<____`]^+?0@#\XVT/MR\&X^+^L'G'L'J
M`@OZBU7\B7WTBUW\"]<C5?@CWXO^"].+WL'O&\'C!0O[BYU@____`]J+5>P#
M^XV4%]R\&X^+??B)50B+U\'B'L'O`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%
M"_J+50C!ZAL+TXN=9/___P/?BWW\`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)
M??`+=0@C?0C!XP4C=?@+]XOZP>\;"_N+G6C___\#WHMU]`/[C9PWW+P;CXM]
M"(OWB5W\P>8>P>\""_>+_HEU"`OZ(_(C??`+_HOSP>X;P>,%"_.+G6S___\#
MWXM]^`/SC;0^W+P;CXOZP><>P>H""_J+WHO7B7WL"U7\(WW\P>,%(U4("]>+
M_L'O&PO[BYUP____`]J+5?`#^XV<%]R\&X^+??R+UXE=^,'B'L'O`@O7B_J)
M5?P+_B/6(WWL"_J+T\'J&\'C!0O3BYUT____`]^+?0@#TXM=_(V4.MR\&X^+
M_L'G'L'N`@O^BW7\"_<CWR-U^(E]](OZ"_.+VL'O&\'C!0O[BYUX____`]Z+
M=>P#^XVT-]R\&X^+??B)=0B+]\'F'L'O`@OWB_H+??2+70B)=?@C_HOR(W7T
MP>,%"_Z+=0C![AL+\XN=?/___P/?`_.+??R-M#[<O!N/B_K!YQ[!Z@(+^HO>
MB]>)??`+50@C?0C!XP4C5?@+UXO^P>\;"_N+78`#VHM5]`/[C9P7W+P;CXM]
M"(O7B5W\P>(>P>\""]>+^HE5"`O^(]8C??`+^HO3P>H;P>,%"].+780#WXM]
M^`/3C90ZW+P;CXO^P><>P>X""_Z+VHOWB7WL"W7\(WW\P>,%(W4("_>+^L'O
M&PO[BUV(`]Z+=?`#^XV<-]R\&X^+??R+]XE=^,'F'L'O`@OWB_Z)=?P+^B/R
M(WWL"_Z+\\'N&\'C!0OSBUV,`]^+?0@#\XM=_(VT/MR\&X^+^L'G'L'J`@OZ
MBU7\"]<CWR-5^(E]](O^"].+WL'O&\'C!0O[BUV0`]J+5>P#^XV4%]R\&X^+
M??B)50B+U\'B'L'O`@O7B_X+??2+70B)5?@C^HO6(U7TP>,%"_J+50C!ZAL+
MTXM=E`/?BWW\`].-E#K<O!N/B_[!YQ[![@(+_HO:B_>)??`+=0@C?0C!XP4C
M=?@+]XOZP>\;"_N+79@#WHMU]`/[C9PWW+P;CXM]"(OWB5W\P>8>P>\""_>+
M^\'O&\'C!0O[BUWP,]Z)=0@SVHMUG`/WB_H#WHMU^,'G'L'J`HVT,];!8LH+
M^HO6B][!ZAO!XP4+TXM="#/?B7WLBWV@,UW\`_J+5?`#WXM]_(V<$];!8LJ+
MU\'B'L'O`@O7B_N)7?B)5?S![QO!XP4+^XM=[#/:BU6D,]X#UXO^`]J+50C!
MYQ[![@(+_HV4$];!8LJ)??2+\HOZBUVHP>X;P><%"_>+??@S??P#WHMU[#-]
M]`/[C9PWUL%BRHM]^(OWB5T(P>8>P>\""_>+^\'O&\'C!8EU^`O[BUVL,_(S
M=?0#WXM]_`/SC;0^UL%BRHOZP><>P>H""_J+UHO>B7WPP>H;P>,%"].+7?@S
MWXM]L#-="`/ZBU7T`]^+?0B-G!/6P6+*B]?!XA[![P(+UXO[B5W\B54(P>\;
MP>,%"_N+7?`SVHM5M#/>`]<#VHM5^(O^P><>P>X"C903UL%BR@O^B_*+VL'N
M&\'C!0OSBUT(B7WL,]^+?;@S7?P#_HMU\`/?BWW\C9PSUL%BRHOWP>8>P>\"
M"_>+^XE=^(EU_,'O&\'C!0O[BUWL,]Z+=;PSV@/WB_H#WHMU",'G'L'J`@OZ
MC;0SUL%BRHE]](O6B_[!ZAO!YP4+UXM]^(M=P#-]_`/:BU7L,WWT`_N-G!?6
MP6+*BWWXB]>)70C!XA[![P(+UXO[P>\;P>,%B57X"_N+7<0SUC-5]`/?BWW\
M`].-E#K6P6+*B_[!YQ[![@(+_HORB]J)??#![AO!XP4+\XM=^#/?BWW(,UT(
M`_Z+=?0#WXM]"(V<,];!8LJ+]\'F'L'O`@OWB_N)7?R)=0C![QO!XP4+^XM=
M\#/>BW7,,]H#]P/>BW7XB_K!YQ[!Z@*-M#/6P6+*"_J+UHO>P>H;P>,%"].+
M70B)?>PSWXM]T#-=_`/ZBU7P`]^-G!/6P6+*BWW\B5WXB]?!XA[![P(+UXO[
MP>\;P>,%"_N+7>R)5?PSVHM5U#/>`]>+_@/:BU4(P><>P>X""_Z-E!/6P6+*
MB7WTB_*+^HM=V,'N&\'G!0OWBWWX,WW\`]Z+=>PS??0#^XV<-];!8LJ+??B+
M]XE=",'F'L'O`@OWB_O![QO!XP6)=?@+^XM=W#/R,W7T`]^+??P#\XVT/M;!
M8LJ+^L'G'L'J`@OZB]:+WHE]\,'J&\'C!0O3BUWX,]^+?>`S70@#^HM5]`/?
MBWT(C9P3UL%BRHO7P>(>P>\""]>)7?R)50B+^\'O&\'C!0O[BUWP,]J+5>0S
MW@/7`]J+5?B+_L'G'L'N`HV4$];!8LJ+70@+_HORB57T,]_![AO!X@4+\HM5
M_#/:`\X#V8M-\`-=Z(MU](V,"];!8LJ)"(M(!`/.B4@$B\K!X1[!Z@(+RHM5
M"`-("(E("(M(#`//7XE(#(M($`/*7HE($%O)PU6+[%-6BW4,BT88BUX4B44,
MB\/!Z`.#X#_&1#`<@$"#^#A^*FI`62O(C40P'%%J`%#HX`@``%;HC>W__VHX
MC48<:@!0Z,T(``"#Q!SK%6HX62O(C40P'%%J`%#HM@@``(/$#(M%#%:+R(A&
M5\'I&(A.5(O(P>D0B$Y5B\B+P_]U",'H&(A&6(O#P>@0B$99B\/!Z0C!Z`B(
M3E:(1EJ(7EOH!@```%E97EM=PU:+="0,5N@3[?__BT0D#%F+#L'I&(@(BP[!
MZ1"(2`&+#L'I"(A(`HH.B$@#BU8$C4X$P>H8B%`$BQ'!ZA"(4`6+$<'J"(A0
M!HH)B$@'BU8(C4X(P>H8B%`(BQ'!ZA"(4`F+$<'J"(A0"HH)B$@+BU8,C4X,
MP>H8B%`,BQ'!ZA"(4`V+$<'J"(A0#HH)B$@/BU80C4X07L'J&(A0$(L1P>H0
MB%`1BQ'!Z@B(4!**"8A($\-6Z,$&``!0Z,T&``"+,.BT!@``4.BZ!@``65E0
M_W0D#.BB!@``4.BN!@``6?\P_U90@\0,A<!U2NB*!@``4.B0!@``9HM`!EEF
M)0#P9CT`0'4PZ'`&``!0Z'P&``"+,%EJ`O]T)`SH7`8``%#H:`8``%G_,/\6
M@\0,A<!U!6H!6%[#,\!>PU:+="0(5U;HP.'__U#HD.'__UF+^%GHF./__X7`
M="B%]G0D5NC*!@``A<!9=!EH.$-``%?_%8A`0`!9.\=9=0=6Z`0```!97U[#
M@>P<`0``4XN<)"0!``!65X7;#X0F`0``4^B+!@``A<!9#X07`0``4^A\!@``
MB_"!Q@(!``#HO04``%#HSP4``(LX65E6Z*T%``!0Z+\%``!9_S#_%XOP4VBD
M0T``5O\5F$!``(U$)"105O\52$!``(/$'(/X_XE$)`P/A+X```!5BRU,0$``
MZP>+G"0P`0``BSV(0$``C40D*&A004``4/_7687`68U$)"A0=1)3:)Q#0`!6
M_Q680$``@\00ZP]HF$-``%;_%9A`0`"#Q`R[E$-``%-6_]>+^%F%_UET'E-7
MZ+T%``!9A<!9=!]HD$-``%?HK`4``%F%P%ET#O9$)!00=$16Z/;^__]9C40D
M%%#_="04_Q500$``687`60^$9?____]T)!#_%51`0`#_M"0T`0``_Q6D0$``
M65E=7UY;@<0<`0``PXU$)"A0_Q400$``B_@SVU;_U87`672LB\-#@_@*?:2%
M_W3L5_\5#$!``.OC48-D)```4U97Z'4$``!0Z,D$``!J`5N(&,<$)'1"0`#H
MDMW__X7`670+@#@Q=0:`>`$`=`7H6N#__VH*4V@01$``Z#P$``!0Z(H$``"#
MQ!"%P`^$H@```(L`.1T\M$``58OSBT`@BW@0?F.]```$`(U&_VH`4%?H!P0`
M`%#H3P0``(/$$(7`=$6+`(M(""/-.\UU!HL`BP#K$VH":@!0Z-\#``!0Z"$$
M``"#Q!!0H4"T0`#_-+#H=`0``%F%P%EU#?]$)!!&.S4\M$``?**A/+1``%V-
M2/\Y3"0,=1T[PXOS?A=7Z)H#``!0Z-8#``!&63LU/+1``%E\Z6H$4V@,1$``
MZ'P#``!0Z,H#``"+\(/$$(7V=#6+!F@`1$``BT`@_S#H7`,``%#HD@,``(L&
M@\0,BT`@BP#V0`E`=`Y0Z$`#``!0Z'`#``!966H$4VC\0T``Z"L#``!0Z'D#
M``"+\(/$$(7V=')HH$%``.A&W/__A<!9=`-0ZTOHI^#__XOXA?]T.8L&5XM`
M(/\PZ/("``!0Z"@#``#HYP(``%#H^0(``(LP@\005^C6`@``4.CH`@``6?\P
M_U8(65GK'*%`M$``_S"+!HM`(/\PZ+,"``!0Z.D"``"#Q`SHI0(``%#H^0(`
M`(`@`.B7`@``4.C!`@``@R``:+!!0`#HN-O__X/$#*,XL$``A<!U$?\U0+1`
M`.@?X?__6:,XL$``Z&("``!0Z(8"``"+,,<$).T!``#_-3BP0`#H2`(``%#H
M;`(``%G_,/\6@\0,A<!?7EMT)8/X$70@@_C_=!M0H4"T0`#_-3BP0`#_,&BL
M0T``Z#4"``"#Q!!9PU6+[%%15HU%#%=0C44(4/\5L$!``#/_5^B%`@``@\0,
M@#@`=4OH<@(``#O'HS2P0`!U(^C4`0``4.CL`0``BS!9:@'HQ`$``%#HW`$`
M`%G_,/]6"%E9_S4TL$``Z#4"``#HI@$``%#H)`(``%F).%GHEP$``%#H#P(`
M`(`(`NB)`0``4.@!`@``@`@!BT4(@\`%B7W\B47X6=]M^%G<'3A$0`#?X)YV
M"V@@1$``Z'X!``!9BT4(C02%%````%#HP0$``%FC0+1``(M-#&H!BPF)"*%`
MM$``QT`$'$1``*%`M$``QT`(6$1``*%`M$``QP4\M$```P```,=`#!A$0`#_
M!3RT0`!8.44(?AZ+#3RT0`"+50R+-4"T0``#R(L4@D")5([\.T4(?.*A/+1`
M`(M-"`/!BPU`M$``5XE\@?RA/+1``(M-"/\U0+1``(U$"/]0:(DX0`#_-32P
M0`#H'`$``(OP@\04._=U#O\U-+!``.@"`0``68OP_S4TL$``Z.X```#'!"1H
M0D``Z+#9__^%P%EU)*$XL$``.\=U%&BP04``Z)C9__\[QUFC.+!``'0'4.@3
M^O__6?\U-+!``.BH````6?\5W$!``(O&7U[)P^@V````4.ALU___6;BH0D``
M:@!04&A!-$``:$!$0`#H%P```%#HK0```(/$&,/,_R4D04``_R4@04``_R4<
M04``_R4804``_R4404``_R4004``_R4,04``_R4(04``_R4$04``_R4`04``
M_R7\0$``_R7X0$``_R7T0$``_R7P0$``_R7L0$``_R7H0$``_R7D0$``_R7@
M0$``_R780$``_R740$``_R700$``_R7,0$``_R7(0$``_R7$0$``_R7`0$``
M_R6\0$``_R6X0$``_R6T0$``_R6L0$``S,S,S,S,S,S,S/\EE$!``/\EC$!`
M`,S,S,Q1/0`0``"-3"0(<A2!Z0`0```M`!```(4!/0`0``!S["O(B\2%`8OA
MBPB+0`10P\S_)6!`0`#_)5Q`0`#,S,S,58OL:O]H`*%``&CP.D``9*$`````
M4&2))0````"#["!35E>)9>B#9?P`:@'_%5A`0`!9@PU8M$``_X,-7+1``/__
M%1A`0`"+#52T0`")"/\5'$!``(L-4+1``(D(H2!`0`"+`*-@M$``Z,````"#
M/3"P0```=0QH9A9``/\5)$!``%GHE````&@,L$``:`BP0`#H?P```*%,M$``
MB478C4784/\U2+1``(U%X%"-1=10C47D4/\5+$!``&@$L$``:`"P0`#H3```
M`/\5,$!``(M-X(D(_W7@_W74_W7DZ!7\__^#Q#")1=Q0_Q4T0$``BT7LBPB+
M"8E-T%!1Z`\```!96<.+9>C_==#_%3Q`0`#_)3A`0`#_)2A`0`!H```#`&@`
M``$`Z`L```!96</#S/\EG$!``/\EH$!`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````""E````````VJ0``/"D``#^I````````,BF``"XI@``J*8``)2F``"(
MI@``>*8``&BF``!@I@``4J8``$JF```RI@``**8``!JF```0I@``!*8``/:E
M``#6I@``XJ4``-BE``#(I0``O*4``+*E``"HI0``GJ4``)2E``"*I0``@*4`
M`'"E``!FI0``7*4``%*E``!(I0``/J4``.BF``#\I@``[*4```````"ZI```
MJ*0``)*D``"$I```<J0``%*D```ZI```)*0``!:D```*I```^J,``.ZC``#<
MHP``R*,``+:C``"FHP``DJ,``(*C``!RHP``9*,``%"C``!`HP``**,``!:C
M```&HP``]J(``.*B``#0H@``O*(``*ZB``"<H@``````````````````0$;6
M20`````"````.P``````````X```.P```%P```!7:6XS,D-/4D4Z.F)O;W1S
M=')A<`````!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC
M````)7,E<R5S```N````4$%27U!23T=.04U%`````%!!4E]414U0`````#$`
M``!005)?0TQ%04X]``!#3$5!3@```%!!4E]'3$]"04Q?0TQ%04X`````4$%2
M7T=,3T)!3%]414U0`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$U01$E2````
M4$%27T=,3T)!3%]$14)51P````!005)?05)'5E\P``!005)?05)'0P````!0
M05)?0T%#2$4```!005)?1$5"54<```!005)?0TQ%04X```!005)?4U!!5TY%
M1`!005)?24Y)5$E!3$E:140`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```````````$193$1?3$E"4D%265]0051(````4$%42`````!,24)2
M05)97U!!5$@`````3$E"4$%42`!,1%],24)205)97U!!5$@`)7,E<W1E;7`M
M)74M)74E<P`````E<R5S=&5M<"TE=25S````)3`R>``````E<R5S8V%C:&4M
M)7,E<P``)7,E<R5S)7,`````<&%R+0`````E<UQT96UP`%=I;D1I<@``4UE3
M5$5-``!54T523D%-10````!54T52`````%1-4`!414U0`````%1%35!$25(`
M5$U01$E2``!#.EQ414U0`%PN+@!<+@``)7,``"5S7"5S````)7-<*BXJ```E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`M(&%B;W)T:6YG('=I=&@@)6DN"@```#````!P97)L+F5X
M90`````8````05)'5@`````M+0``+64``'!A;FEC.B!M96UO<GD@=W)A<```
M````````@/___\]!26YT97)N86QS.CI005(Z.D)/3U0`````(R$O=7-R+V)I
M;B]P97)L#0H-"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PT*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`T*#0IP86-K86=E(%]?<&%R7W!L.PT*#0HC("TM+2!4:&ES('-C<FEP
M="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM
M+0T*(R!U<V4@<W1R:6-T.PT*#0HC;&EN92`Q-3D-"@T*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[#0I%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2![#0H@("`@<F5Q=6ER92!&:6QE.CI496UP.PT*("`@(')E<75I
M<F4@1FEL93HZ0F%S96YA;64[#0H@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PT*
M("`@(&UY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PT*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")]*3L-"B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L-"B`@("!R;61I
M<B`D<&%R7W1E;7`[#0H@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U
M<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PT*("`@(",@
M=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@T*#0H@("`@:68@*"UD("1P87)?
M=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![#0H@("`@("`@(",@4V]M971H
M:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T
M;W)Y+B`@5&AI<PT*("`@("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L
M871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN:VEN9R!S:&%R960-"B`@("`@
M("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S
M92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD#0H@("`@("`@(",@<VAE;&P@
M8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@
M=&AI<R!P<F]C97-S+@T*("`@("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N
M(%=I;F1O=W,@8F5C875S92!O=7(@<&%R96YT('!R;V-E<W,@=VEL;`T*("`@
M("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N#0H-"B`@
M("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`T*("`@("`@("`@("`@
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP-"B`@("`@("`@("`@($1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P-"B`@("`@("`@("`@
M(%-51D9)6"`]/B`G+F-M9"<L#0H@("`@("`@("`@("!53DQ)3DL@/3X@,"P-
M"B`@("`@("`@*3L-"@T*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@-
M"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O#0H@("!R;2`M<F8@)R1P
M87)?=&5M<"<-"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@T*
M("`@("`@(&)R96%K#0H@("!F:0T*("`@<VQE97`@,0T*("`@>#U@97AP<B!<
M)'@@*R`Q8`T*9&]N90T*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G#0HB
M.PT*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L-"B`@
M("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<[#0H@("`@("`@(&-L;W-E("1T;7`[#0H@("`@("`@('-Y<W1E
M;2@D8VUD*3L-"B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D-"B`@("`@("`@("`@("`N
M("1T;7`M/F9I;&5N86UE*3L-"B`@("!]#0I]('T-"@T*0D5'24X@>PT*("`@
M($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0[#0H-"B`@("!E=F%L('L-"@T*7W!A<E]I;FET7V5N=B@I
M.PT*#0II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%2
M7T%21U9?,'T@*2![#0H@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?
M)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L-"B`@("`D,"`]("1%
M3E9[4$%27T%21U9?,'T[#0I]#0IE;'-E('L-"B`@("!F;W(@*&ME>7,@)45.
M5BD@>PT*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O
M.PT*("`@('T-"GT-"@T*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L-
M"@T*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051(#0IM>2`E
M0V]N9FEG(#T@*`T*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`T*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@
M+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL#0H@("`@
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P-"BD[#0H-"E]S971?<')O9VYA;64H*3L-"E]S971?<&%R7W1E;7`H
M*3L-"@T*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@
M8G5N9&QE9"!M;V1U;&5S('M[>PT*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O
M<RD[#0I[#0H@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[#0H-
M"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C
M=&EO;B![>WL-"B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L-"B`@("!B:6YM;V1E*%]&2"D[#0H-"B`@("!M>2`D8G5F.PT*("`@('-E
M96L@7T9(+"`M."P@,CL-"B`@("!R96%D(%]&2"P@)&)U9BP@.#L-"B`@("!L
M87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL-"@T*("`@('-E96L@
M7T9(+"`M,3(L(#([#0H@("`@<F5A9"!?1D@L("1B=68L(#0[#0H@("`@<V5E
M:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PT*("`@(')E860@
M7T9(+"`D8G5F+"`T.PT*#0H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[#0H@("`@(R!]?7T-"@T*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@
M:6YT;R!M96UO<GD@>WM[#0H@("`@;7D@)7)E<75I<F5?;&ES=#L-"B`@("!W
M:&EL92`H)&)U9B!E<2`B1DE,12(I('L-"B`@("`@("`@<F5A9"!?1D@L("1B
M=68L(#0[#0H@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L-"@T*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F.PT*("`@("`@
M("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D[#0H@
M("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968[#0H@("`@("`@(&UY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L-"@T*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L-"B`@("`@("`@<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PT*#0H@("`@("`@(&EF("AD969I
M;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@
M>PT*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I
M;&4H)&5X="P@)&-R8RD[#0H@("`@("`@("`@("!I9B`H)&]U="D@>PT*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[#0H@("`@("`@("`@("`@("`@
M<')I;G0@)&]U="`D8G5F.PT*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[
M#0H@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PT*("`@
M("`@("`@("`@?0T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PT*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PT*("`@
M("`@("!]#0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL
M:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L-"B`@("`@("`@
M("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I#0H@("`@("`@
M("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE
M)&5X="([#0H@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L-"B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@
M;W(@9&EE("0A.PT*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L-"B`@("`@
M("`@("`@('!R:6YT("1O=70@)&)U9CL-"B`@("`@("`@("`@(&-L;W-E("1O
M=70[#0H@("`@("`@('T-"B`@("`@("`@96QS92![#0H@("`@("`@("`@("`D
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![#0H@("`@("`@("`@
M("`@("`@8G5F(#T^("1B=68L#0H@("`@("`@("`@("`@("`@8W)C(#T^("1C
M<F,L#0H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L#0H@("`@
M("`@("`@("!].PT*("`@("`@("!]#0H@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PT*("`@('T-"B`@("`C('U]?0T*#0H@("`@;&]C86P@0$E.0R`]("AS
M=6(@>PT*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[#0H-"B`@
M("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PT*#0H@
M("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5]('Q\(&1O('L-"B`@("`@("`@("`@(&UY("1K97D[#0H@("`@("`@
M("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L-"B`@("`@("`@
M("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL-"B`@("`@("`@
M("`@("`@("`D:V5Y(#T@)%\[(&QA<W0[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D
M*"1K97DI.PT*("`@("`@("!](&]R(')E='5R;CL-"@T*("`@("`@("`D24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PT*#0H@
M("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2![#0H@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W7W1M<&9I;&4@;W(@9&EE("0A.PT*("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PT*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT[
M#0H@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D[#0H@("`@("`@("`@("!R
M971U<FX@)&9H.PT*("`@("`@("!]#0H@("`@("`@(&5L<V4@>PT*("`@("`@
M("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I
M;&5N86UE+3Y[8W)C?2D[#0H@("`@("`@("`@("!I9B`H)&]U="D@>PT*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D[#0H@("`@("`@("`@("`@("`@
M<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PT*("`@("`@("`@("`@("`@
M(&-L;W-E("1O=70[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!O<&5N
M(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$[#0H@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D[#0H@("`@("`@("`@("!R971U<FX@)&9H.PT*("`@("`@
M("!]#0H-"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B([#0H@("`@?2P@0$E.0RD[#0H-"B`@("`C
M($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PT*#0H@("`@(R!I;FET
M:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PT*("`@(')E<75I<F4@
M6%-,;V%D97([#0H@("`@<F5Q=6ER92!005(Z.DAE879Y.PT*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD[#0H@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M#0H@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PT*#0H@("`@
M(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W
M:71H:6X-"B`@("!R97%U:7)E($E/.CI&:6QE.PT*#0H@("`@(R!L;V%D(')E
M<W0@;V8@=&AE(&=R;W5P(&EN#0H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L-"B`@("`@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL-"B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I
M;&5N86UE(#U^("]"4T1004XO*2![#0H@("`@("`@("`@("`C(')E<75I<F4@
M;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PT*("`@("`@("`@
M("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![#0H@("`@("`@("`@
M("`@("`@<F5Q=6ER92`D9FEL96YA;64[#0H@("`@("`@("`@("!]#0H@("`@
M("`@("`@("!E;'-E('L-"B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E
M4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z#0H@("`@("`@("`@("`@
M("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T
M;VUI>F5<+G!L)"\[#0H@("`@("`@("`@("!]#0H@("`@("`@('T-"B`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L-"B`@("!]#0H-
M"B`@("`C('U]?0T*#0H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S
M7#`P-"([#0H@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PT*?0T*
M(R!]?7T-"@T*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PT*;7D@0'!A<E]A
M<F=S.PT*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PT*#0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT[#0H-"B,@
M1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B
M;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PT*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![#0H@
M("`@;7D@)61I<W1?8VUD(#T@<7<H#0H@("`@("`@('`@("!B;&EB7W1O7W!A
M<@T*("`@("`@("!I("`@:6YS=&%L;%]P87(-"B`@("`@("`@=2`@('5N:6YS
M=&%L;%]P87(-"B`@("`@("`@<R`@('-I9VY?<&%R#0H@("`@("`@('8@("!V
M97)I9GE?<&%R#0H@("`@*3L-"@T*("`@(&UY($!A9&1?=&]?:6YC.PT*("`@
M('=H:6QE("A`05)'5BD@>PT*("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PT*#0H@("`@("`@(&EF("@D
M,2!E<2`G22<I('L-"B`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R
M.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L-"B`@
M("`@("`@("`@(&5V86P@(G5S92`D,B([#0H@("`@("`@('T-"B`@("`@("`@
M96QS:68@*"0Q(&5Q("=!)RD@>PT*("`@("`@("`@("`@=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M3R<I('L-"B`@("`@("`@("`@("1O=70@/2`D,CL-"B`@("`@("`@?0T*("`@
M("`@("!E;'-I9B`H)#$@97$@)V(G*2![#0H@("`@("`@("`@("`D8G5N9&QE
M(#T@)W-I=&4G.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M0B<I('L-"B`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL-"B`@("`@("`@
M?0T*("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2![#0H@("`@("`@("`@("`D
M<75I970@/2`Q.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M3"<I('L-"B`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([#0H@("`@("`@('T-"B`@
M("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PT*("`@("`@("`@("`@)&-A8VAE
M7VYA;64@/2`D,CL-"B`@("`@("`@?0T*#0H@("`@("`@('-H:69T*$!!4D=6
M*3L-"@T*("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L-
M"B`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PT*("`@("`@
M("`@("`@:6YI=%]I;F,H*3L-"B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$
M:7-T.PT*("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8[#0H@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PT*("`@("`@("`@("`@97AI=#L-"B`@("`@("`@?0T*
M("`@('T-"@T*("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[#0I]#0H-
M"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0T*#0HC('U]?0T*
M#0HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM[#0II9B`H)&]U="D@
M>PT*("`@('L-"B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&
M24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL-"B`@("`@("`@<F5Q=6ER92!)
M3SHZ1FEL93L-"B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`[#0H@("`@
M?0T*#0H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L-"B`@("!M>2`D>FEP
M.PT*#0H-"B`@("!I9B`H9&5F:6YE9"`D<&%R*2![#0H@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z
M("0A(CL-"B`@("`@("`@8FEN;6]D92@D9F@I.PT*("`@("`@("!B;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PT*#0H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL-"B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0T*("`@("`@
M("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PT*("`@('T-
M"@T*#0H@("`@;7D@)65N=B`](&1O('L-"B`@("`@("`@:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L-"B`@
M("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PT*("`@("`@("`@
M("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,[#0H@("`@("`@("`@("`D;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[#0H@("`@("`@('T-"B`@("!].PT*
M#0H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM[#0H@("`@
M;&]C86P@)"\@/2!<-#L-"@T*("`@(&EF("AD969I;F5D("1P87(I('L-"B`@
M("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL-
M"B`@("`@("`@8FEN;6]D92A005(I.PT*("`@("`@("!D:64@(B1P87(@:7,@
M;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([
M#0H@("`@?0T*#0H@("`@0W)E871E4&%T:"@D;W5T*2`[#0H@("`@#0H@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@-"B`@("`@("`@)&]U="P-"B`@("`@
M("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P-"B`@("`@("`@,#<W-RP-"B`@("`I
M(&]R(&1I92`D(3L-"B`@("!B:6YM;V1E*"1F:"D[#0H-"B`@("`D+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[#0H@("`@
M<V5E:R!?1D@L(#`L(#`[#0H@("`@;7D@)&QO861E<B`]('-C86QA<B`\7T9(
M/CL-"B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L-"B`@("`@("`@<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`[#0H@("`@("`@(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I#0H@("`@?0T*("`@(&9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L-"B`@("`@("`@;7D@)'9A
M;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L-"B`@("`@("`@)'9A;"`](&5V86P@
M)'9A;"!I9B`D=F%L(#U^("]>6R<B72\[#0H@("`@("`@(&UY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL-"B`@("`@("`@;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL-"B`@("`@("`@
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PT*("`@("`@("`@("`@)&UA9VEC
M("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI
M#0H@("`@("`@('UE9SL-"B`@("!]#0H@("`@)&9H+3YP<FEN="@D;&]A9&5R
M*3L-"B`@("`D+R`]('5N9&5F.PT*("`@(",@?7U]#0H-"B`@("`C(%=R:71E
M(&)U;F1L960@;6]D=6QE<R![>WL-"B`@("!I9B`H)&)U;F1L92D@>PT*("`@
M("`@("!R97%U:7)E(%!!4CHZ2&5A=GD[#0H@("`@("`@(%!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L-"B`@("`@("`@:6YI=%]I;F,H*3L-"@T*
M("`@("`@("!R97%U:7)E7VUO9'5L97,H*3L-"@T*("`@("`@("!M>2!`:6YC
M(#T@<V]R="![#0H@("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H
M)&$I#0H@("`@("`@('T@9W)E<"![#0H@("`@("`@("`@("`A+T)31%!!3B\-
M"B`@("`@("`@?2!G<F5P('L-"B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S
M:71E)RD@;W(-"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD#0H@("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L-"B`@("`@("`@?2!`24Y#.PT*#0H@("`@
M("`@(&EF("@D0V]N9FEG>U]D96QI;7T@97$@)UQ<)RD@>R!S>UQ<?7LO?6<@
M9F]R($!I;F,@?0T*#0H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E
M9"!T;R!F:7@@4E0@(S0Q-SDP.@T*("`@("`@("`C($9U;FYY+"!N;VXM97AI
M<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A
M=71O<W!L:70N:7@N#0H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I
M>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N#0H@("`@("`@
M(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD
M97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`T*("`@("`@("`C($D@9F%I
M;&5D+B`M+2!3=&5F9F5N#0H@("`@("`@(&UY("5F:6QE<SL-"B`@("`@("`@
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH[#0H@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,[
M#0H-"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T[#0H@("`@("`@(&UY("5W<FET=&5N.PT*#0H@("`@("`@(&9O<F5A
M8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L-"B`@("`@("`@("`@(&UY("@D;F%M
M92P@)&9I;&4I.PT*#0H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I
M;F,I('L-"B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PT*("`@("`@("`@("`@("`@("`@("`D9FEL
M92`]("1?.PT*("`@("`@("`@("`@("`@("`@("!L87-T.PT*("`@("`@("`@
M("`@("`@('T-"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2![#0H@("`@("`@("`@("`@("`@("`@("@D9FEL
M92P@)&YA;64I(#T@*"0Q+"`D,BD[#0H@("`@("`@("`@("`@("`@("`@(&QA
M<W0[#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@("`@(&5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PT*("`@("`@("`@
M("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD,7TI('L-"B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L-"B`@("`@("`@("`@("`@("`@("`@("`@
M(&QA<W0[#0H@("`@("`@("`@("`@("`@("`@('T-"B`@("`@("`@("`@("`@
M("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PT*("`@("`@("`@("`@("`@
M("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[#0H@
M("`@("`@("`@("`@("`@("`@("`@("!L87-T.PT*("`@("`@("`@("`@("`@
M("`@("!]#0H@("`@("`@("`@("`@("`@?0T*("`@("`@("`@("`@?0T*#0H@
M("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL[#0H@("`@("`@("`@("!N97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL-"B`@("`@
M("`@("`@(&]U=',H(&IO:6X@(B(L#0H@("`@("`@("`@("`@("`@<7$H4&%C
M:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`T*
M("`@("`@("`@("`@("`@('%Q*"(N+BXI#0H@("`@("`@("`@("`I.PT*#0H@
M("`@("`@("`@("!M>2`D8V]N=&5N=#L-"B`@("`@("`@("`@(&EF("AR968H
M)&9I;&4I*2![#0H@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT[#0H@("`@("`@("`@("!]#0H@("`@("`@("`@("!E;'-E('L-"B`@
M("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#
M86XG="!O<&5N("1F:6QE.B`D(2([#0H@("`@("`@("`@("`@("`@8FEN;6]D
M92A&24Q%*3L-"B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL-
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PT*#0H@("`@("`@("`@("`@
M("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I#0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L-"@T*
M("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P
M(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT#0H@("`@("`@("`@("`@("`@)&-O
M;G1E;G0@/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y
M.R\-"B`@("`@("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")8
M4TQO861E<BYP;2(I.PT*("`@("`@("`@("`@?0T*#0H@("`@("`@("`@("!O
M=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PT*("`@("`@("`@("`@)&9H
M+3YP<FEN="@B1DE,12(I.PT*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L-"B`@("`@("`@("`@("1F:"T^
M<')I;G0H<W!R:6YT9B@-"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64-"B`@
M("`@("`@("`@("DI.PT*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PT*("`@("`@("`@("`@)&9H+3YP<FEN
M="@D8V]N=&5N="D[#0H@("`@("`@('T-"B`@("!]#0H@("`@(R!]?7T-"@T*
M("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S
M('M[>PT*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L-"@T*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L-"B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L-"B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T-"B`@
M("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG
M97-T.CI32$$Q+3YN97<@?0T*("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L-"@T*("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y#0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PT*("`@("`@("!I9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M#0H@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PT*("`@("`@("!]#0H@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PT*("`@("`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L-"B`@("`@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1F:"D[#0H@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L-
M"B`@("`@("`@("`@('T-"B`@("`@("`@?0T*#0H@("`@("`@("1C86-H95]N
M86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L-"B`@("!]
M#0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D[#0H@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL-"B`@("`D
M9F@M/G!R:6YT*"1C86-H95]N86UE*3L-"B`@("`D9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L-"B`@("`D9F@M
M/G!R:6YT*")<;E!!4BYP;5QN(BD[#0H@("`@)&9H+3YC;&]S93L-"B`@("!C
M:&UO9"`P-S4U+"`D;W5T.PT*("`@(",@?7U]#0H-"B`@("!E>&ET.PT*?0T*
M(R!]?7T-"@T*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A
M8VAE('M[>PT*>PT*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O
M<SL-"@T*("`@(%]F:7A?<')O9VYA;64H*3L-"@T*("`@(",@3F]W(&QO860@
M=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[
M>PT*("`@(')E<75I<F4@4$%2.PT*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L-"@T*#0H@("`@>PT*("`@("`@("`C;&]C86P@)$E.0WLG
M0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PT*("`@
M("`@("!R97%U:7)E($9I;&4Z.D9I;F0[#0H@("`@("`@(')E<75I<F4@07)C
M:&EV93HZ6FEP.PT*("`@('T-"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<[#0H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL-"B`@("`D9F@M
M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([#0H@
M("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PT*#0H@
M("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L-"B`@("`D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L-"@T*("`@("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT[#0H@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB*2D[#0H-"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$-"B`@
M("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L-
M"B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD[#0H@
M("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L-"B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PT*("`@("`@("`@("`@("`@(%X-"B`@("`@("`@("`@("`@("`O/W-H;&EB
M+PT*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N
M?2\I/PT*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\-"B`@("`@("`@("`@("`@("`H6UXO72LI#0H@("`@("`@("`@
M("`@("`@)`T*("`@("`@("`@("`@?7@[#0H@("`@("`@("`@("!M>2`D97AT
M<F%C=%]N86UE(#T@)#$[#0H@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@
M1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?
M;F%M92D[#0H@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PT*("`@("`@("`@
M("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@
M:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[#0H@("`@("`@
M("`@("!](&5L<V4@>PT*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L-"B`@("`@
M("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D[#0H@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL-"B`@("`@("`@("`@('T-"B`@("`@("`@
M?0T*("`@('T-"B`@("`C('U]?0T*?0T*(R!]?7T-"@T*(R!)9B!T:&5R92=S
M(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![#0H@("`@9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8[#0I5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=#0H@
M("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(-"BX-"B`@
M("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L-"GT-"B,@?7U]#0H-"G-U8B!#<F5A=&50871H('L-"B`@("!M
M>2`H)&YA;64I(#T@0%\[#0H@("`@#0H@("`@<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L-"B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[#0H@("`@
M#0H@("`@<F5Q=6ER92!&:6QE.CI0871H.PT*("`@(`T*("`@($9I;&4Z.E!A
M=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@
M9&EE<R!W:71H(&5R<F]R#0I]#0H-"G-U8B!R97%U:7)E7VUO9'5L97,@>PT*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<[#0H-"B`@("!R97%U:7)E(&QI8CL-"B`@("!R97%U:7)E
M($1Y;F%,;V%D97([#0H@("`@<F5Q=6ER92!I;G1E9V5R.PT*("`@(')E<75I
M<F4@<W1R:6-T.PT*("`@(')E<75I<F4@=V%R;FEN9W,[#0H@("`@<F5Q=6ER
M92!V87)S.PT*("`@(')E<75I<F4@0V%R<#L-"B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PT*("`@(')E<75I<F4@17)R;F\[#0H@("`@<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD[#0H@("`@<F5Q=6ER92!%>'!O<G1E<CL-"B`@("!R97%U
M:7)E($9C;G1L.PT*("`@(')E<75I<F4@1FEL93HZ5&5M<#L-"B`@("!R97%U
M:7)E($9I;&4Z.E-P96,[#0H@("`@<F5Q=6ER92!84TQO861E<CL-"B`@("!R
M97%U:7)E($-O;F9I9SL-"B`@("!R97%U:7)E($E/.CI(86YD;&4[#0H@("`@
M<F5Q=6ER92!)3SHZ1FEL93L-"B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB
M.PT*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PT*("`@(')E<75I<F4@4$%2
M.PT*("`@(')E<75I<F4@4$%2.CI(96%V>3L-"B`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L-"B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L-"B`@
M("!E=F%L('L@<F5Q=6ER92!#=V0@?3L-"B`@("!E=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PT*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PT*
M("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PT*
M("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T[
M#0I]#0H-"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I
M;B!M>6QD<B]M:W1M<&1I<BYC#0HC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN
M(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A#0IS=6(@7W-E
M=%]P87)?=&5M<"![#0H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PT*("`@("`@("`D<&%R
M7W1E;7`@/2`D,3L-"B`@("`@("`@<F5T=7)N.PT*("`@('T-"@T*("`@(&9O
M<F5A8V@@;7D@)'!A=&@@*`T*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P-"B`@("`@
M("`@<7<H($,Z7%Q414U0("]T;7`@+B`I#0H@("`@*2![#0H@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L-"B`@("`@("`@;7D@)'5S97)N86UE.PT*("`@("`@("!M>2`D<'=U
M:60[#0H@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@T*("`@
M("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT[#0H-"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.
M86UE*2`I('L-"B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PT*("`@("`@("!]#0H@("`@("`@(&5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PT*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PT*("`@
M("`@("!]#0H@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL-
M"B`@("`@("`@?0T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<[#0H-
M"B`@("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP
M87(M)'5S97)N86UE(CL-"B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34[
M#0H@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@
M/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PT*("`@("`@("`@("`@;W!E;B`H
M;7D@)&9H+"`B/"(N("1P<F]G;F%M92D[#0H@("`@("`@("`@("!S965K("1F
M:"P@+3$X+"`R.PT*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L
M(#8[#0H@("`@("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L-"B`@
M("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PT*("`@("`@("`@("`@
M("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L-"B`@("`@("`@("`@("`@("`D
M8G5F(#U^(',O7#`O+V<[#0H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PT*("`@("`@("`@("`@
M?0T*("`@("`@("`@("`@96QS92![#0H@("`@("`@("`@("`@("`@;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T-"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]#0H@("`@("`@
M("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T[#0H-"B`@("`@("`@("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y#0H@
M("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E
M<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`[#0H@("`@("`@("`@("`@("`@:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PT*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[#0H@("`@("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@("`@(&5L<V4@>PT*("`@("`@("`@("`@("`@("`@("!I
M9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L-"B`@
M("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L-"B`@("`@("`@
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D[#0H@("`@("`@("`@("`@("`@
M("`@('T-"B`@("`@("`@("`@("`@("!]#0H-"B`@("`@("`@("`@("`@("`D
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PT*("`@("`@("`@("`@?0T*
M("`@("`@("`@("`@8VQO<V4H)&9H*3L-"B`@("`@("`@?0T*("`@("`@("!E
M;'-E('L-"B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$[#0H@("`@
M("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M#0H@("`@("`@('T-"@T*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PT*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L-"B`@("`@("`@
M;&%S=#L-"B`@("!]#0H-"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PT*?0T*#0IS
M=6(@7W1E;7!F:6QE('L-"B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL-"B`@
M("!M>2`H)&9H+"`D9FEL96YA;64I.PT*#0H@("`@)&9I;&5N86UE(#T@(B1P
M87)?=&5M<"\D8W)C)&5X="([#0H-"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]
M*2![#0H@("`@("`@('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE
M.PT*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64[#0H@("`@?0T*
M("`@(&5L<V4@>PT*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I
M(&EF("@M<B`D9FEL96YA;64I.PT*("`@('T-"@T*("`@(&]P96X@)&9H+"`G
M/B<L("1F:6QE;F%M92!O<B!D:64@)"$[#0H@("`@8FEN;6]D92@D9F@I.PT*
M("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D[#0I]#0H-"B,@<V%M92!C;V1E
M(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N86UE#0IS
M=6(@7W-E=%]P<F]G;F%M92![#0H@("`@:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M#0H@("`@("`@("1P<F]G;F%M92`]("0Q.PT*("`@('T-"@T*("`@("1P<F]G
M;F%M92!\?#T@)#`[#0H-"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L-"B`@("`@
M("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PT*("`@('T-"@T*("`@(&EF
M("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`^/2`P*2![#0H@("`@("`@(&EF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L-"B`@("`@("`@("`@(')E='5R;B!I9B`M
M<R`D9F@[#0H@("`@("`@('T-"B`@("`@("`@:68@*"US("(D<')O9VYA;64D
M0V]N9FEG>U]E>&5](BD@>PT*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#
M;VYF:6=[7V5X97T[#0H@("`@("`@("`@("!R971U<FX[#0H@("`@("`@('T-
M"B`@("!]#0H-"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![#0H@("`@("`@(&YE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PT*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<
M120O+SL-"B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D-"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2([#0H@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D-"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL-"B`@("!]#0I]#0H-
M"G-U8B!?9FEX7W!R;V=N86UE('L-"B`@("`D,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PT*("`@(&EF("AI;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![#0H@("`@("`@("1P<F]G;F%M92`]
M("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL-"B`@("!]#0H-"B`@("`C
M(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PT*("`@(&UY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0T*("`@("`@
M("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L-"B`@("!C:&]M<"@D<'=D*3L-"B`@("`D
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D
M<'=D)$-O;F9I9WM?9&5L:6U]+SL-"@T*("`@("1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L-"GT-"@T*<W5B(%]P87)?:6YI=%]E;G8@>PT*("`@
M(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L-"B`@("`@
M("`@<F5T=7)N.PT*("`@('T@96QS92![#0H@("`@("`@("1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#([#0H@("`@?0T*#0H@("`@9F]R("AQ=R@@4U!!5TY%
M1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P
M("D@*2![#0H@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT[#0H@("`@
M?0T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L-
M"B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L-"B`@("!]
M#0H-"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL-"@T*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PT*
M("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PT*("`@('T-"B`@("!E
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![#0H@("`@
M("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D[#0H@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[#0H@("`@?0T*?0T*#0IS
M=6(@;W5T<R![#0H@("`@<F5T=7)N(&EF("1Q=6EE=#L-"B`@("!I9B`H)&QO
M9V9H*2![#0H@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B([#0H@("`@?0T*
M("`@(&5L<V4@>PT*("`@("`@("!P<FEN="`B0%]<;B([#0H@("`@?0T*?0T*
M#0IS=6(@:6YI=%]I;F,@>PT*("`@(')E<75I<F4@0V]N9FEG.PT*("`@('!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H#0H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C
M:&5X<"!S:71E;&EB97AP#0H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP#0H@("`@*3L-"GT-"@T*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C#0HC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX-
M"@T*<&%C:V%G92!M86EN.PT*#0IR97%U:7)E(%!!4CL-"G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PT*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L-
M"@T*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0T*("`@('5N
M;&5S<R`M92`D<')O9VYA;64[#0H-"F1O("1P<F]G;F%M93L-"D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[#0ID:64@
M)$`@:68@)$`[#0H-"GT[#0H-"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L-"GT-
M"@T*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PT*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL-
M"@T*,3L-"@T*(VQI;F4@,3`P,@T*#0I?7T5.1%]?#0H`<&%R+G!L``#_____
ML#I``,0Z0``<H@````````````#.I```K$```'BA`````````````!*E```(
M0```<*$`````````````,*4```!```"(H0`````````````^I@``&$``````
M````````````````````````(*4```````#:I```\*0``/ZD````````R*8`
M`+BF``"HI@``E*8``(BF``!XI@``:*8``&"F``!2I@``2J8``#*F```HI@``
M&J8``!"F```$I@``]J4``-:F``#BI0``V*4``,BE``"\I0``LJ4``*BE``">
MI0``E*4``(JE``"`I0``<*4``&:E``!<I0``4J4``$BE```^I0``Z*8``/RF
M``#LI0```````+JD``"HI```DJ0``(2D``!RI```4J0``#JD```DI```%J0`
M``JD``#ZHP``[J,``-RC``#(HP``MJ,``*:C``"2HP``@J,``'*C``!DHP``
M4*,``$"C```HHP``%J,```:C``#VH@``XJ(``-"B``"\H@``KJ(``)RB````
M````'05B;V]T7U=I;C,R0T]210``X0-097)L7VYE=UA3`````U!E<FQ?9V5T
M7V-O;G1E>'0``!P%8F]O=%]$>6YA3&]A9&5R`&<"4&5R;%]4<W1A=&)U9E]P
M='(`MP!097)L7TE,24]?<'1R`+H`4&5R;%])365M7W!T<@"^`%!E<FQ?25!R
M;V-?<'1R``#&`E!E<FQ?8W)O86M?;F]C;VYT97AT``"U`%!E<FQ?241I<E]P
M='(`U@!097)L7TEC;VUP8W9?<'1R``"4`U!E<FQ?;6=?<V5T`+D$4&5R;%]S
M=E]S971P=@""`E!E<FQ?879?<VAI9G0`:@1097)L7W-V7S)P=E]F;&%G<P![
M`E!E<FQ?879?9F5T8V@`(@-097)L7V=V7V9E=&-H<'8`:P)097)L7U1T86EN
M=&5D7W!T<@`9!5!E<FQ?=VEN,S)?=&5R;0`G!7!E<FQ?9G)E90`F!7!E<FQ?
M9&5S=')U8W0`*@5P97)L7W)U;@``*05P97)L7W!A<G-E```?!%!E<FQ?<V%F
M97-Y<VUA;&QO8P``]P!097)L7TEE>&ET7V9L86=S7W!T<@``8@%097)L7TEP
M97)L7V1E<W1R=6-T7VQE=F5L7W!T<@`E!7!E<FQ?8V]N<W1R=6-T```?!7!E
M<FQ?86QL;V,``)@`4&5R;%]'9&]?=6YD=6UP7W!T<@`8!5!E<FQ?=VEN,S)?
M:6YI=`#B`U!E<FQ?;F5W6%-?9FQA9W,``'!E<FPU."YD;&P``"0!1V5T36]D
M=6QE1FEL94YA;65!``"T`$9R965,:6)R87)Y`"8!1V5T36]D=6QE2&%N9&QE
M00``2T523D5,,S(N9&QL``#7`$=E=%5S97).86UE00``041605!),S(N9&QL
M``"R`G-P<FEN=&8`N`)S=')C;7```,<"<W1R=&]K``"^`G-T<FQE;@``Q0)S
M=')S='(``&T`7U]P7U]E;G9I<F]N``"8`FUE;6UO=F4`P0)S=')N8W!Y`,`"
M<W1R;F-M<`#(`%]E<G)N;P``@@%?;6MD:7(``(X!7W!C='EP90`5`5]I<V-T
M>7!E``!A`%]?;6)?8W5R7VUA>```EP)M96UC<'D``)D";65M<V5T``"9`5]R
M;61I<@``WP!?9FEN9&-L;W-E``#B`%]F:6YD;F5X=`#=`5]U;FQI;FL`X`!?
M9FEN9&9I<G-T``"_`5]S=')D=7``Q0%?<W1R;FEC;7``35-60U)4+F1L;```
MTP!?97AI=`!(`%]88W!T1FEL=&5R`$D"97AI=```9`!?7W!?7U]I;FET96YV
M`%@`7U]G971M86EN87)G<P`/`5]I;FET=&5R;0"#`%]?<V5T=7-E<FUA=&AE
M<G(``)T`7V%D:G5S=%]F9&EV``!J`%]?<%]?8V]M;6]D90``;P!?7W!?7V9M
M;V1E``"!`%]?<V5T7V%P<%]T>7!E``#*`%]E>&-E<'1?:&%N9&QE<C,``+<`
M7V-O;G1R;VQF<```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````4$%``$Q!0`#_____^*!``)]<
M```````````````````!````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````#``,````H``"`#@```$@``(`0
M````8```@````````````````````@`!````>```@`(```"0``"`````````
M```````````!`&4```"H``"````````````````````!``$```#```"`````
M```````````````!``````#8```````````````````````!``````#H````
M```````````````````!``````#X```````````````````````!```````(
M`0``F,,``&@%``````````````#)``"H"`````````````"HT0``(@``````
M````````(,$``'0"````````````````````````=`(T````5@!3`%\`5@!%
M`%(`4P!)`$\`3@!?`$D`3@!&`$\``````+T$[_X```$`````````````````
M`````#\````!````!``$``$```````````````````#4`0```0!3`'0`<@!I
M`&X`9P!&`&D`;`!E`$D`;@!F`&\```"P`0```0`P`#0`,``P`#``-`!B`#``
M```8`````0!#`&\`;0!M`&4`;@!T`',````@`````0!#`&\`;0!P`&$`;@!Y
M`$X`80!M`&4``````"@````!`$8`:0!L`&4`1`!E`',`8P!R`&D`<`!T`&D`
M;P!N```````@`````0!&`&D`;`!E`%8`90!R`',`:0!O`&X``````"`````!
M`$D`;@!T`&4`<@!N`&$`;`!.`&$`;0!E````)`````$`3`!E`&<`80!L`$,`
M;P!P`'D`<@!I`&<`:`!T````*`````$`3`!E`&<`80!L`%0`<@!A`&0`90!M
M`&$`<@!K`',``````"@````!`$\`<@!I`&<`:0!N`&$`;`!&`&D`;`!E`&X`
M80!M`&4````@`````0!0`'(`:0!V`&$`=`!E`$(`=0!I`&P`9````"`````!
M`%``<@!O`&0`=0!C`'0`3@!A`&T`90``````)`````$`4`!R`&\`9`!U`&,`
M=`!6`&4`<@!S`&D`;P!N````(`````$`4P!P`&4`8P!I`&$`;`!"`'4`:0!L
M`&0```!$`````0!6`&$`<@!&`&D`;`!E`$D`;@!F`&\``````"0`!````%0`
M<@!A`&X`<P!L`&$`=`!I`&\`;@````````2P!``````H````$````"`````!
M``@````````!```````````````!`````0``!@8&``0$!``"`@(``````$)"
M0@"=G9T`;FYN`(&!@0"QL;$`____`'-S<P"?GY\`6%A8`+*RL@#]_?T`:VMK
M`/S\_`#7U]<`%A86`-K:V@"6EI8`CHZ.`$9&1@#+R\L`"PL+`*"@H`#^_OX`
MR<G)`,'!P0`#`P,`$1$1`).3DP"SL[,`[N[N`/3T]`#CX^,`Y>7E`**BH@"Z
MNKH`KZ^O``<'!P!Q<7$`M;6U`/7U]0")B8D`BHJ*`#0T-`#HZ.@`-34U`%I:
M6@"WM[<`V-C8`-#0T``='1T`#`P,`(^/CP"^OKX`;6UM``D)"0";FYL`+R\O
M`,W-S0#9V=D`&1D9`$U-30!$1$0`4%!0`#P\/`!D9&0`PL+"`#(R,@`("`@`
M#0T-``\/#P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````%!04%!04%!04%!04%!00$!`35`(P5!,4-!041%
M+@$!`0$!`0$%`3P7%P$!$P$!`0$!`0$!%0$!)A4!`0\!`0$!`0$!`1,!$0$%
M-0$F`0$!`0$!`0$B$A`Q#P4!(`$!`0$!`0$!$`H@(A45+B$N`0$!`0$?("$0
M(A`C(R4F)P$!`0$E$!`0$!`0$!`0%T4!`0%!$!`0$!`0$!`0$!`7`0$!#Q`0
M%1`0$!`0$!`0`0$!`1(0$!,?$!`0$!`0!P$!`0$@$!`0`0\0$!`0$0$!`0$!
M!R`0"@$!!1`0$#$!`0$!`0$!`0$!`0%!!0\!`0$!`0$!`0$!`0$!`0$!`0$!
M`0&``0``P`$``.`#``#P`P``\`,``/`#``#@`P``P`$``(`!``"``0``@`,`
M`(`#````!P````<``(X/``#_'P``*````"````!``````0`(````````!```
M`````````````0````$````````!`0$``@("``,#`P`$!`0`!04%``8&!@`'
M!P<`"`@(``D)"0`*"@H`"PL+``P,#``-#0T`#@X.``\/#P`0$!``$1$1`!(2
M$@`3$Q,`%!04`!45%0`6%A8`%Q<7`!@8&``9&1D`&AH:`!L;&P`<'!P`'1T=
M`!X>'@`?'Q\`("`@`"$A(0`B(B(`(R,C`"0D)``E)24`)B8F`"<G)P`H*"@`
M*2DI`"HJ*@`K*RL`+"PL`"TM+0`N+BX`+R\O`#`P,``Q,3$`,C(R`#,S,P`T
M-#0`-34U`#8V-@`W-S<`.#@X`#DY.0`Z.CH`.SL[`#P\/``]/3T`/CX^`#\_
M/P!`0$``04%!`$)"0@!#0T,`1$1$`$5%10!&1D8`1T='`$A(2`!)24D`2DI*
M`$M+2P!,3$P`34U-`$Y.3@!/3T\`4%!0`%%140!24E(`4U-3`%145`!5554`
M5E96`%=75P!86%@`65E9`%I:6@!;6UL`7%Q<`%U=70!>7EX`7U]?`&!@8`!A
M86$`8F)B`&-C8P!D9&0`965E`&9F9@!G9V<`:&AH`&EI:0!J:FH`:VMK`&QL
M;`!M;6T`;FYN`&]O;P!P<'``<7%Q`')R<@!S<W,`='1T`'5U=0!V=G8`=W=W
M`'AX>`!Y>7D`>GIZ`'M[>P!\?'P`?7U]`'Y^?@!_?W\`@("``(&!@0""@H(`
M@X.#`(2$A`"%A84`AH:&`(>'AP"(B(@`B8F)`(J*B@"+BXL`C(R,`(V-C0".
MCHX`CX^/`)"0D`"1D9$`DI*2`).3DP"4E)0`E965`):6E@"7EY<`F)B8`)F9
MF0":FIH`FYN;`)R<G`"=G9T`GIZ>`)^?GP"@H*``H:&A`**BH@"CHZ,`I*2D
M`*6EI0"FIJ8`IZ>G`*BHJ`"IJ:D`JJJJ`*NKJP"LK*P`K:VM`*ZNK@"OKZ\`
ML+"P`+&QL0"RLK(`L[.S`+2TM`"UM;4`MK:V`+>WMP"XN+@`N;FY`+JZN@"[
MN[L`O+R\`+V]O0"^OKX`O[^_`,#`P`#!P<$`PL+"`,/#PP#$Q,0`Q<7%`,;&
MQ@#'Q\<`R,C(`,G)R0#*RLH`R\O+`,S,S`#-S<T`SL[.`,_/SP#0T-``T='1
M`-+2T@#3T],`U-34`-75U0#6UM8`U]?7`-C8V`#9V=D`VMK:`-O;VP#<W-P`
MW=W=`-[>W@#?W]\`X.#@`.'AX0#BXN(`X^/C`.3DY`#EY>4`YN;F`.?GYP#H
MZ.@`Z>GI`.KJZ@#KZ^L`[.SL`.WM[0#N[NX`[^_O`/#P\`#Q\?$`\O+R`//S
M\P#T]/0`]?7U`/;V]@#W]_<`^/CX`/GY^0#Z^OH`^_O[`/S\_`#]_?T`_O[^
M`/___P`T-#0\/#P\/#P\/#P\/#P\/#P\/#P\/#PL#`0$!`0$!%RTU-34U-34
MU-34U-S4U-34U-34U-34U+0T400$!`0$9,SL]/3T_/3\]/3T_/3\]/ST_/S\
M]/3LQ#11400$!`1DQ.3L]/3T]/3T]/3T]/3T]/3T]/3T[.R\-%%1400$!&3$
MY.SL[.3L[.SDY.3D[.SD[.3L[.SLY+PT45%1400$9+SD[.RLC*S4Q)24G)2,
MC)24E)R<G.S<O#1145%1401DO-SD[.3$492L9.2D3#0L7,3,4;34Y-R\-%%1
M45%1462\W.3D[.3D481TY(QLI)QLC+QTK-3DW+PT!`0$!`0$9+S<Y.3LY.2\
M48S4U(RLS'3,W*11Q.3<O#0$!`0$!`1DO-SDY.3DY-R,?)RT?(2<;,SDO'3$
MY-RT-`0$!`0$!%R\W-SDY.3DU)RD7)2,S#R49,R\C%'<U+0T!`0$!`0$9+34
MW-S<Y-R,C*PLO+3,6L1DG&R4I-S4M#0$!`0$!`1<M-3<W.3<W'24U$RD](P\
MU'24=)Q,W,RT-`0$!`0$!&2TU-S<W.3<=%'T=(3LS&3D?&RDM&RDU+0T!`0$
M!`0$9+3,W-S,?(R$M/S,Q/STM/R\9,RLA%&\K#0$!`0$!`1<M,S4S(RDW-SL
M_/S\_/ST_.RT[*Q\E%&L-`0$!`0$!%RLS,QLG/3\_/S\_/S\_/S\_/S\Q)2,
M4:PT!`0$!`0$7*S$O'SD_/S\_/S\_/S\_/S\_/SLS*Q1K#0$!`0$!`1<K+1,
MQ/S\_.ST_/S\_/S\_/S\_/2\4<2L-`0$!`0$!%RLM$S4_/STM-S\_/S\_/S\
M_/S\S%',Q*0T!`0$!`0$7*S$I%'\_/RTG/3\_/S\_/S\_/244<S$I"P$!`0$
M!`1<I*11A.S\_,QDM.S\_/S\_/S\U&RLS+RD-`0$!`0$!%RD9'2\]/S\Q%&$
MG.3\_/S\_.2,4<S,Q*0T!`0$!`0$7*1LC.3T_/R<4<Q1E.S\_/S\O'3,S,2\
MG"P$!`0$!`1<I*QD7&2DI%&LS,1TE.3T_.11O,S,Q+R<-`0$!`0$!%RDM+R\
MC%%1Q,3,S*Q1?'R4;'R\S,3$O)PL!`0$!`0$7)R\Q,3$Q,3$Q,3$Q,1145%1
MO,3$Q,2TG#0$!`0$!`14G+3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,3$O+2<+`0$!`0$
M!%2<O,3$O+R\O+R\O+R\O+R\O+R\O+R\M)PL!`0$!`0$7)RTQ+RTM+2TM+2T
MM+2TM+2TM+2TM+2LG"P$!`0$!`14A)2<G)24E)24E)24E)24E)24E)24E)2$
M)`0$!`0$!$147%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%0T!`0$!`0$````/P``
M`!\````/````!P````,````!`````````#\````_````/P```#\````_````
M/P```#\````_````/P```#\````_````/P```#\````_````/P```#\````_
M````/P```#\````_````/P```#\````_````/P```#\```$``@`0$````0`(
M`&@%```!`"`@```!``@`J`@```(`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!.0C$P`````$!&UDD!````1CI<4&5R;%]04$U<4$%2
<+5!A8VME<BTP+CDY,5QM>6QD<EQP87(N<&1B````
